/*
 * Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package copy

import (
    "os"
    "os/exec"
    "path/filepath"
    "strings"
    "gitlab.nrao.edu/ssa/gocapo/capo/config"
    "gitlab.nrao.edu/ssa/gocapo/helpers"
)

//checkError
/**
 * Check if an error happened and panic on it if so
 *
 * @param err An error object to report
 **/
func checkError(err error) {
    if err != nil {
        panic(err)
    }
}

/**
 * Copy a given GMVA directory from the GMVA source directory to the VLBI
 * staging directory
 *
 * @param dir A string with the name of the GMVA directory
 **/
func CopyGmva(dir string)  {
    capoProperties, err := config.InitConfig(os.Getenv("CAPO_PROFILE"), helpers.DefaultCapoPath)
    checkError(err)

    wsIngestionSettings := capoProperties.SettingsForPrefix("edu.nrao.workspaces.IngestionSettings")
    gmvaSourcePath := wsIngestionSettings.GetString("gmvaSourceDirectory")
    aatIngestionSettings := capoProperties.SettingsForPrefix("archive-ingestion")
    difxPath := aatIngestionSettings.GetString("VLBAPath")

    // GMVA source only copies files starting with GMVA
    gmvaSourceFiles := strings.Join([]string{gmvaSourcePath, dir, "GMVA*"}, "/")
    var gmvaSourcePaths []string
    gmvaSourcePaths, err = filepath.Glob(gmvaSourceFiles)
    checkError(err)

    difxDir := strings.Join([]string{difxPath, dir}, "/")

    // First make the directory to copy files to
    mkdirCmd := exec.Command("mkdir", difxDir)
    err = mkdirCmd.Run()
    checkError(err)

    for _, path := range gmvaSourcePaths {
        copyCmd := exec.Command("cp", "-LR", path, difxDir)
        err = copyCmd.Run()
        checkError(err)
    }
}
